
// Copyright (c) 2023 Dominic Masters
// 
// This software is released under the MIT License.
// https://opensource.org/licenses/MIT

#include "scenes/SceneList.hpp"
#include "component/display/Camera.hpp"

#include "component/ui/UICanvas.hpp"
#include "ui/elements/UIRectangle.hpp"
#include "ui/elements/UILabel.hpp"
#include "ui/UIMenu.hpp"
#include "ui/container/UIRowContainer.hpp"
#include "ui/container/UIPaddingContainer.hpp"
#include "component/vn/VNManager.hpp"

using namespace Dawn;

void Dawn::vnScene(Scene &s) {
  // Load assets
  // auto testj = s.getGame()->assetManager.get<json>("test");
  auto texture = s.getGame()->assetManager.get<TrueTypeTexture>("font_silver", 32);
  while(!s.getGame()->assetManager.isEverythingLoaded()) {
    s.getGame()->assetManager.update();
  }

  // Setup camera
  auto cameraItem = s.createSceneItem();
  auto camera = cameraItem->addComponent<Camera>();
  cameraItem->lookAt({ 3, 3, 3 }, { 0, 0, 0 }, { 0, 1, 0 });
  camera->clipFar = 99999.99f;

  // Create canvas
  auto canvasItem = s.createSceneItem();
  auto canvas = canvasItem->addComponent<UICanvas>();
  
  auto vnManager = canvasItem->addComponent<VNManager>();
  vnManager->canvas = canvas;
  vnManager->texture = texture;
  vnManager->setText(L"broivvoib");
}